<a id="aea.helpers.git"></a>

# aea.helpers.git

Useful git tools.

<a id="aea.helpers.git.check_working_tree_is_dirty"></a>

#### check`_`working`_`tree`_`is`_`dirty

```python
def check_working_tree_is_dirty() -> bool
```

Check if the current Git working tree is dirty.

**Returns**:

True if the working tree is not dirty, False otherwise

